@@ -458,4 +458,11 @@ impl FastlyHttpReq for Session {
 
         Ok(outcome)
     }
+
+    fn close(&mut self, req_handle: RequestHandle) -> Result<(), Error> {
+        // We don't do anything with the parts, but we do pass the error up if
+        // the handle given doesn't exist
+        self.take_request_parts(req_handle)?;
+        Ok(())
+    }
 }
